﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace DigitalMultimeter
{
    static class Constants
    {
        public const double MEASUREMENT_CYCLE_DEFAULT = 1;
        public const int LOG_OUTPUT_CYCLE = 5;
        public const int LOG_OUTPUT_MAX = 1000;

        public const double VOLTAGE_A_DEFAULT = 1;
        public const double VOLTAGE_B_DEFAULT = 0;
        public const double CURRENT_A_DEFAULT = 1;
        public const double CURRENT_B_DEFAULT = 0;
        public const double RESISTANCE_H_A_DEFAULT = 1;
        public const double RESISTANCE_H_B_DEFAULT = 0;
        public const double RESISTANCE_L_A_DEFAULT = 1;
        public const double RESISTANCE_L_B_DEFAULT = 0;
        public const double CAPACITANCE_A_DEFAULT = 1;
        public const double CAPACITANCE_B_DEFAULT = 0;
        public const double FREQUENCY_A_DEFAULT = 1;
        public const double FREQUENCY_B_DEFAULT = 0;

        // 測定データのヘッダーとフッター
        public const byte MEASUREMENT_HEADER1 = 0x44;   // 'D'
        public const byte MEASUREMENT_FOOTER1 = 0x0D;   // '\r'
        public const byte MEASUREMENT_FOOTER2 = 0x0A;   // '\n'
        // 測定データの各種データの位置とサイズ
        public const int MEASUREMENT_TOTAL_DATA_SIZE = 47;
        public const int MEASUREMENT_VOLTAGE_TOP_IDX = 1;   // 電圧情報　先頭位置
        public const int MEASUREMENT_VOLTAGE_DATA_SIZE = 6; // 電圧情報　データサイズ
        public const int MEASUREMENT_CURRENT_TOP_IDX = 9;   // 電流情報　先頭位置
        public const int MEASUREMENT_CURRENT_DATA_SIZE = 6; // 電流情報　データサイズ
        public const int MEASUREMENT_CAPACITANCE_TOP_IDX = 16;  // 容量情報　先頭位置
        public const int MEASUREMENT_CAPACITANCE_DATA_SIZE = 7; // 容量情報　データサイズ
        public const int MEASUREMENT_RESISTANCE_H_TOP_IDX = 24;  // 高抵抗情報　先頭位置
        public const int MEASUREMENT_RESISTANCE_H_DATA_SIZE = 6; // 高抵抗情報　データサイズ
        public const int MEASUREMENT_RESISTANCE_L_TOP_IDX = 31;  // 低抵抗情報　先頭位置
        public const int MEASUREMENT_RESISTANCE_L_DATA_SIZE = 5; // 低抵抗情報　データサイズ
        public const int MEASUREMENT_FREQUENCY_TOP_IDX = 37;  // 周波数情報　先頭位置
        public const int MEASUREMENT_FREQUENCY_DATA_SIZE = 8; // 周波数情報　データサイズ

        public const double MEASUREMENT_RESISTANCE_H_RANGE_OVER_VAL = 1000;
        public const double MEASUREMENT_RESISTANCE_L_RANGE_OVER_VAL = 10000;
        public const string MEASUREMENT_RESISTANCE_H_RANGE_OVER_MSG = "OVER 1M";
        public const string MEASUREMENT_RESISTANCE_L_RANGE_OVER_MSG = "OVER 10k";   

        public const string INIT_FILE_NAME = "dmm_init_setting.xml";
        //public const string CORRECTION_FILE_NAME = "dmm_correction.xml";
    }
    public class MeasureVal
    {
        public double voltage;
        public double current;
        public double resistance_h;
        public double resistance_l;
        public double capacitance;
        public double frequency;

        public MeasureVal()
        {
            try
            {
                voltage = 0;
                current = 0;
                resistance_h = 0;
                resistance_l = 0;
                capacitance = 0;
                frequency = 0;
            }
            catch
            {
            }
        }

        public int Init()
        {
            int ret = 0;
            try
            {
                voltage = 0;
                current = 0;
                resistance_h = 0;
                resistance_l = 0;
                capacitance = 0;
                frequency = 0;
            }
            catch
            {
            }
            return ret;
        }
        public int Dispose()
        {
            int ret = 0;
            try
            {
            }
            catch
            {
            }
            return ret;
        }
    }
    [Serializable()]
    public class SettingVal
    {
        [System.Xml.Serialization.XmlElement("MEASUREMENT_CYCLE")]
        public double measurement_cycle;
        [System.Xml.Serialization.XmlElement("LOG_OUTPUT_CYCLE")]
        public int log_output_cycle;
        [System.Xml.Serialization.XmlElement("LOG_OUTPUT_MAX")]
        public int log_output_max;

        [System.Xml.Serialization.XmlElement("VOLTAGE_A")]
        public double voltage_a;
        [System.Xml.Serialization.XmlElement("VOLTAGE_B")]
        public double voltage_b;
        [System.Xml.Serialization.XmlElement("CURRENT_A")]
        public double current_a;
        [System.Xml.Serialization.XmlElement("CURRENT_B")]
        public double current_b;
        [System.Xml.Serialization.XmlElement("RESISTANCE_H_A")]
        public double resistance_h_a;
        [System.Xml.Serialization.XmlElement("RESISTANCE_H_B")]
        public double resistance_h_b;
        [System.Xml.Serialization.XmlElement("RESISTANCE_L_A")]
        public double resistance_l_a;
        [System.Xml.Serialization.XmlElement("RESISTANCE_L_B")]
        public double resistance_l_b;
        [System.Xml.Serialization.XmlElement("CAPACITANCE_A")]
        public double capacitance_a;
        [System.Xml.Serialization.XmlElement("CAPACITANCE_B")]
        public double capacitance_b;
        [System.Xml.Serialization.XmlElement("FREQUENCY_A")]
        public double frequency_a;
        [System.Xml.Serialization.XmlElement("FREQUENCY_B")]
        public double frequency_b;

        public SettingVal()
        {
            try
            {
                measurement_cycle = Constants.MEASUREMENT_CYCLE_DEFAULT;
                log_output_cycle = Constants.LOG_OUTPUT_CYCLE;
                log_output_max = Constants.LOG_OUTPUT_MAX;

                voltage_a = Constants.VOLTAGE_A_DEFAULT;
                voltage_b = Constants.VOLTAGE_B_DEFAULT;
                current_a = Constants.CURRENT_A_DEFAULT;
                current_b = Constants.CURRENT_B_DEFAULT;
                resistance_h_a = Constants.RESISTANCE_H_A_DEFAULT;
                resistance_h_b = Constants.RESISTANCE_H_B_DEFAULT;
                resistance_l_a = Constants.RESISTANCE_L_A_DEFAULT;
                resistance_l_b = Constants.RESISTANCE_L_B_DEFAULT;
                capacitance_a = Constants.CAPACITANCE_A_DEFAULT;
                capacitance_b = Constants.CAPACITANCE_B_DEFAULT;
                frequency_a = Constants.FREQUENCY_A_DEFAULT;
                frequency_b = Constants.FREQUENCY_B_DEFAULT;
            }
            catch
            {
            }
        }

        public int Init()
        {
            int ret = 0;
            try
            {
                measurement_cycle = Constants.MEASUREMENT_CYCLE_DEFAULT;
                log_output_cycle = Constants.LOG_OUTPUT_CYCLE;
                log_output_max = Constants.LOG_OUTPUT_MAX;

                voltage_a = Constants.VOLTAGE_A_DEFAULT;
                voltage_b = Constants.VOLTAGE_B_DEFAULT;
                current_a = Constants.CURRENT_A_DEFAULT;
                current_b = Constants.CURRENT_B_DEFAULT;
                resistance_h_a = Constants.RESISTANCE_H_A_DEFAULT;
                resistance_h_b = Constants.RESISTANCE_H_B_DEFAULT;
                resistance_l_a = Constants.RESISTANCE_L_A_DEFAULT;
                resistance_l_b = Constants.RESISTANCE_L_B_DEFAULT;
                capacitance_a = Constants.CAPACITANCE_A_DEFAULT;
                capacitance_b = Constants.CAPACITANCE_B_DEFAULT;
                frequency_a = Constants.FREQUENCY_A_DEFAULT;
                frequency_b = Constants.FREQUENCY_B_DEFAULT;
            }
            catch
            {
            }
            return ret;
        }
        public int Dispose()
        {
            int ret = 0;
            try
            {
            }
            catch
            {
            }
            return ret;
        }
    }

    [Serializable()]
    public class CorrectionVal
    {
        [System.Xml.Serialization.XmlElement("VOLTAGE_A")]
        public double voltage_a;
        [System.Xml.Serialization.XmlElement("VOLTAGE_B")]
        public double voltage_b;
        [System.Xml.Serialization.XmlElement("CURRENT_A")]
        public double current_a;
        [System.Xml.Serialization.XmlElement("CURRENT_B")]
        public double current_b;
        [System.Xml.Serialization.XmlElement("RESISTANCE_H_A")]
        public double resistance_h_a;
        [System.Xml.Serialization.XmlElement("RESISTANCE_H_B")]
        public double resistance_h_b;
        [System.Xml.Serialization.XmlElement("RESISTANCE_L_A")]
        public double resistance_l_a;
        [System.Xml.Serialization.XmlElement("RESISTANCE_L_B")]
        public double resistance_l_b;
        [System.Xml.Serialization.XmlElement("CAPACITANCE_A")]
        public double capacitance_a;
        [System.Xml.Serialization.XmlElement("CAPACITANCE_B")]
        public double capacitance_b;
        [System.Xml.Serialization.XmlElement("FREQUENCY_A")]
        public double frequency_a;
        [System.Xml.Serialization.XmlElement("FREQUENCY_B")]
        public double frequency_b;


        public CorrectionVal()
        {
            try
            {
                voltage_a = Constants.VOLTAGE_A_DEFAULT;
                voltage_b = Constants.VOLTAGE_B_DEFAULT;
                current_a = Constants.CURRENT_A_DEFAULT;
                current_b = Constants.CURRENT_B_DEFAULT;
                resistance_h_a = Constants.RESISTANCE_H_A_DEFAULT;
                resistance_h_b = Constants.RESISTANCE_H_B_DEFAULT;
                resistance_l_a = Constants.RESISTANCE_L_A_DEFAULT;
                resistance_l_b = Constants.RESISTANCE_L_B_DEFAULT;
                capacitance_a = Constants.CAPACITANCE_A_DEFAULT;
                capacitance_b = Constants.CAPACITANCE_B_DEFAULT;
                frequency_a = Constants.FREQUENCY_A_DEFAULT;
                frequency_b = Constants.FREQUENCY_B_DEFAULT;
            }
            catch
            {
            }
        }

        public int Init()
        {
            int ret = 0;
            try
            {
                voltage_a = Constants.VOLTAGE_A_DEFAULT;
                voltage_b = Constants.VOLTAGE_B_DEFAULT;
                current_a = Constants.CURRENT_A_DEFAULT;
                current_b = Constants.CURRENT_B_DEFAULT;
                resistance_h_a = Constants.RESISTANCE_H_A_DEFAULT;
                resistance_h_b = Constants.RESISTANCE_H_B_DEFAULT;
                resistance_l_a = Constants.RESISTANCE_L_A_DEFAULT;
                resistance_l_b = Constants.RESISTANCE_L_B_DEFAULT;
                capacitance_a = Constants.CAPACITANCE_A_DEFAULT;
                capacitance_b = Constants.CAPACITANCE_B_DEFAULT;
                frequency_a = Constants.FREQUENCY_A_DEFAULT;
                frequency_b = Constants.FREQUENCY_B_DEFAULT;
            }
            catch
            {
            }
            return ret;
        }
        public int Dispose()
        {
            int ret = 0;
            try
            {
            }
            catch
            {
            }
            return ret;
        }
    }
}
